==> ELO_utils-1.0.1.tar.gz: ELO_utils-1.0.1/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os
import sys
import datetime
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = 'ELO_utils'
DESCRIPTION = 'ELO calculations for python'
URL = 'https://github.com/danybeam/ELO_Utils'
EMAIL = 'danybeam@gmail.com'
AUTHOR = 'danybeam'
REQUIRES_PYTHON = '>=3.7.0'
VERSION = None
LICENSE = 'MIT'

# What packages are required for this module to be executed?
REQUIRED = []

# What packages are optional?
EXTRAS = {}

#####################################################

here = os.path.abspath(os.path.dirname(__file__))

try:
    with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
        long_description = '\n' + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    with open(os.path.join(here, '__version__.py')) as f:
        exec(f.read(), about)
else:
    about['__version__'] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('{0}:: {1}'.format(datetime.datetime.now(), s))
        print('#############################################')

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        #self.status('Uploading the package to PyPI via Twine…')
        #os.system('twine upload dist/*')

        self.status('Pushing git tags…')
        os.system('git tag v{0}'.format(about['__version__']))
        os.system('git push --tags')
        
        sys.exit()

class TestCommand(Command):
    """Support setup.py test."""

    description = 'test the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('{0}:: {1}'.format(datetime.datetime.now(), s))
        print('#############################################')

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        self.status('Running tests')
        os.system('python -m pytest')
        input('press any key to finish')
        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about['__version__'],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=('tests',)),
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license=LICENSE,
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Operating System :: OS Independent',
    ],
    
    cmdclass={
        'upload': UploadCommand,
        'test': TestCommand
    },
)

==> ELO_utils-1.0.3.tar.gz: ELO_utils-1.0.3/setup.py <==
#!/usr/bin/env python
# -*- coding: utf-8 -*-

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os
import sys
import datetime
from shutil import rmtree

from setuptools import find_packages, setup, Command

# Package meta-data.
NAME = 'ELO_utils'
DESCRIPTION = 'ELO calculations for python'
URL = 'https://github.com/danybeam/ELO_Utils'
EMAIL = 'danybeam@gmail.com'
AUTHOR = 'danybeam'
REQUIRES_PYTHON = '>=3.7.0'
VERSION = None
LICENSE = 'MIT'

# What packages are required for this module to be executed?
REQUIRED = []

# What packages are optional?
EXTRAS = {}

#####################################################

here = os.path.abspath(os.path.dirname(__file__))

try:
    with io.open(os.path.join(here, 'README.md'), encoding='utf-8') as f:
        long_description = '\n' + f.read()
except FileNotFoundError:
    long_description = DESCRIPTION

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    with open(os.path.join(here, '__version__.py')) as f:
        exec(f.read(), about)
else:
    about['__version__'] = VERSION


class UploadCommand(Command):
    """Support setup.py upload."""

    description = 'Build and publish the package.'
    user_options = [
        ('user=', 'u', "Specify the user"),
        ('password=', 'p', "Specify the user password")
    ]

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('{0}:: {1}'.format(datetime.datetime.now(), s))
        print('#############################################')

    def initialize_options(self):
        self.user = None
        self.password = None

    def finalize_options(self):
        pass

    def run(self):
        try:
            self.status('Removing previous builds…')
            rmtree(os.path.join(here, 'dist'))
        except OSError:
            pass

        self.status('Building Source and Wheel (universal) distribution…')
        os.system('{0} setup.py sdist bdist_wheel --universal'.format(sys.executable))

        self.status('Uploading the package to PyPI via Twine…')
        if self.user and self.password:
            os.system('twine upload dist/* -u {0} -p {1}'.format(self.user,self.password))
        else:
             os.system('python -m twine upload dist/*')
        self.status('Pushing git tags…')
        os.system('git tag v{0}'.format(about['__version__']))
        os.system('git push --tags')
        
        sys.exit()

class TestCommand(Command):
    """Support setup.py test."""

    description = 'test the package.'
    user_options = []

    @staticmethod
    def status(s):
        """Prints things in bold."""
        print('{0}:: {1}'.format(datetime.datetime.now(), s))
        print('#############################################')

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        self.status('Running tests')
        os.system('python -m pytest')
        input('press any key to finish')
        sys.exit()


# Where the magic happens:
setup(
    name=NAME,
    version=about['__version__'],
    description=DESCRIPTION,
    long_description=long_description,
    long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=find_packages(exclude=('tests',)),
    install_requires=REQUIRED,
    extras_require=EXTRAS,
    include_package_data=True,
    license=LICENSE,
    classifiers=[
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Operating System :: OS Independent',
    ],
    
    cmdclass={
        'upload': UploadCommand,
        'test': TestCommand
    },
)
